@@ -1,5 +1,5 @@
 import asyncio
-from abstract_apis import get_url,make_endpoint,get_headers
+from abstract_apis import get_url,make_endpoint,get_headers,get_async_response
 def getSolcatcherUrl():
   return 'https://solcatcher.io'
 def getEndpointUrl(endpoint=None,url=None):
@@ -16,16 +16,3 @@ def ifListGetSection(listObj,section=0):
         if len(listObj)>section:
             return listObj[section]
     return listObj
-def get_async_response(async_function, *args, **kwargs):
-    try:
-        loop = asyncio.get_event_loop()
-    except RuntimeError:
-        loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(loop)
-
-    if not loop.is_running():
-        # Only run the loop if it's not already running
-        return loop.run_until_complete(async_function(*args, **kwargs))
-    else:
-        # If the loop is already running, directly run the coroutine
-        return asyncio.ensure_future(async_function(*args, **kwargs))
